summaryrefslogtreecommitdiff
path: root/src/tests/test_contract.c
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2016-03-01 16:16:36 +0100
committerChristian Grothoff <christian@grothoff.org>2016-03-01 16:16:36 +0100
commit94059c0329921b422b1c7f27d946b0f550fe7978 (patch)
treecd4adc78a6d0687b5b6f12512184a9db1cc2d5aa /src/tests/test_contract.c
parent281d39c6afbd4133ab1f13acd0915276f45a9b57 (diff)
downloadmerchant-94059c0329921b422b1c7f27d946b0f550fe7978.tar.gz
merchant-94059c0329921b422b1c7f27d946b0f550fe7978.tar.bz2
merchant-94059c0329921b422b1c7f27d946b0f550fe7978.zip
mint->exchange renaming
Diffstat (limited to 'src/tests/test_contract.c')
-rw-r--r--src/tests/test_contract.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/tests/test_contract.c b/src/tests/test_contract.c
index 71a8968a..f48ed613 100644
--- a/src/tests/test_contract.c
+++ b/src/tests/test_contract.c
@@ -81,7 +81,7 @@ run (void *cls, char *const *args, const char *cfgfile,
{
json_t *j_fake_contract;
json_t *j_details;
- json_t *j_mints;
+ json_t *j_exchanges;
json_t *j_item;
json_t *j_amount;
json_t *j_tax_amount;
@@ -253,8 +253,8 @@ run (void *cls, char *const *args, const char *cfgfile,
"merchant", j_merchant,
"L-names", j_lnames);
- /* Faking out the mints' list */
- j_mints = json_pack ("[{s:s}]",
+ /* Faking out the exchanges' list */
+ j_exchanges = json_pack ("[{s:s}]",
"demo.taler.net",
"Q1WVGRGC1F4W7RYC6M23AEGFEXQEHQ730K3GG0B67VPHQSRR75H0");
@@ -262,7 +262,7 @@ run (void *cls, char *const *args, const char *cfgfile,
"amount", j_amount,
"max fee", j_max_fee,
"trans_id", json_integer_value (j_id),
- "mints", j_mints,
+ "exchanges", j_exchanges,
"details", j_details);
#if 0
str = json_dumps (j_fake_contract, JSON_INDENT(2) | JSON_PRESERVE_ORDER);